altitudo package
================

Submodules
----------

altitudo.altitudo module
------------------------

.. automodule:: altitudo.altitudo
    :members:
    :undoc-members:
    :show-inheritance:

altitudo.cli module
-------------------

.. automodule:: altitudo.cli
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: altitudo
    :members:
    :undoc-members:
    :show-inheritance:
